@@ -1,4 +1,3 @@
-from os import path
 import sys
 
 from . import context  # noqa
@@ -6,9 +5,7 @@ from . import op  # noqa
 from .runtime import environment
 from .runtime import migration
 
-__version__ = '1.3.1'
-
-package_dir = path.abspath(path.dirname(__file__))
+__version__ = "1.4.2"
 
 sys.modules["alembic.migration"] = migration
 sys.modules["alembic.environment"] = environment
