@@ -3,9 +3,9 @@ import logging
 import re
 
 from sqlalchemy import event
+from sqlalchemy import inspect
 from sqlalchemy import schema as sa_schema
 from sqlalchemy import types as sqltypes
-from sqlalchemy.engine.reflection import Inspector
 from sqlalchemy.util import OrderedSet
 
 from alembic.ddl.base import _fk_spec
@@ -34,7 +34,7 @@ def _produce_net_changes(autogen_context, upgrade_ops):
     connection = autogen_context.connection
     include_schemas = autogen_context.opts.get("include_schemas", False)
 
-    inspector = Inspector.from_engine(connection)
+    inspector = inspect(connection)
 
     default_schema = connection.dialect.default_schema_name
     if include_schemas:
@@ -376,7 +376,9 @@ class _ix_constraint_sig(_constraint_sig):
         self.is_unique = bool(const.unique)
 
     def md_name_to_sql_name(self, context):
-        return sqla_compat._get_index_final_name(context.dialect, self.const)
+        return sqla_compat._get_constraint_final_name(
+            self.const, context.dialect
+        )
 
     @property
     def column_names(self):
@@ -499,6 +501,7 @@ def _compare_indexes_and_uniques(
             conn_indexes,
             metadata_unique_constraints,
             metadata_indexes,
+            autogen_context.dialect,
         )
 
     # 3. give the dialect a chance to omit indexes and constraints that
@@ -537,7 +540,6 @@ def _compare_indexes_and_uniques(
 
     conn_uniques_by_name = dict((c.name, c) for c in conn_unique_constraints)
     conn_indexes_by_name = dict((c.name, c) for c in conn_indexes)
-
     conn_names = dict(
         (c.name, c)
         for c in conn_unique_constraints.union(conn_indexes)
@@ -726,6 +728,7 @@ def _correct_for_uq_duplicates_uix(
     conn_indexes,
     metadata_unique_constraints,
     metadata_indexes,
+    dialect,
 ):
     # dedupe unique indexes vs. constraints, since MySQL / Oracle
     # doesn't really have unique constraints as a separate construct.
@@ -733,25 +736,38 @@ def _correct_for_uq_duplicates_uix(
     # that already seem to be defined one way or the other
     # on that side.  This logic was formerly local to MySQL dialect,
     # generalized to Oracle and others. See #276
+
+    # resolve final rendered name for unique constraints defined in the
+    # metadata.   this includes truncation of long names.  naming convention
+    # names currently should already be set as cons.name, however leave this
+    # to the sqla_compat to decide.
+    metadata_cons_names = [
+        (sqla_compat._get_constraint_final_name(cons, dialect), cons)
+        for cons in metadata_unique_constraints
+    ]
+
     metadata_uq_names = set(
-        [
-            cons.name
-            for cons in metadata_unique_constraints
-            if cons.name is not None
-        ]
+        name for name, cons in metadata_cons_names if name is not None
     )
 
     unnamed_metadata_uqs = set(
         [
             _uq_constraint_sig(cons).sig
-            for cons in metadata_unique_constraints
-            if cons.name is None
+            for name, cons in metadata_cons_names
+            if name is None
         ]
     )
 
     metadata_ix_names = set(
-        [cons.name for cons in metadata_indexes if cons.unique]
+        [
+            sqla_compat._get_constraint_final_name(cons, dialect)
+            for cons in metadata_indexes
+            if cons.unique
+        ]
     )
+
+    # for reflection side, names are in their final database form
+    # already since they're from the database
     conn_ix_names = dict(
         (cons.name, cons) for cons in conn_indexes if cons.unique
     )
@@ -895,6 +911,64 @@ def _render_server_default_for_compare(
         return None
 
 
+def _normalize_computed_default(sqltext):
+    """we want to warn if a computed sql expression has changed.  however
+    we don't want false positives and the warning is not that critical.
+    so filter out most forms of variability from the SQL text.
+
+    """
+
+    return re.sub(r"[ \(\)'\"`\[\]]", "", sqltext).lower()
+
+
+def _compare_computed_default(
+    autogen_context,
+    alter_column_op,
+    schema,
+    tname,
+    cname,
+    conn_col,
+    metadata_col,
+):
+    rendered_metadata_default = str(
+        metadata_col.server_default.sqltext.compile(
+            dialect=autogen_context.dialect,
+            compile_kwargs={"literal_binds": True},
+        )
+    )
+
+    # since we cannot change computed columns, we do only a crude comparison
+    # here where we try to eliminate syntactical differences in order to
+    # get a minimal comparison just to emit a warning.
+
+    rendered_metadata_default = _normalize_computed_default(
+        rendered_metadata_default
+    )
+
+    if isinstance(conn_col.server_default, sa_schema.Computed):
+        rendered_conn_default = str(
+            conn_col.server_default.sqltext.compile(
+                dialect=autogen_context.dialect,
+                compile_kwargs={"literal_binds": True},
+            )
+        )
+        if rendered_conn_default is None:
+            rendered_conn_default = ""
+        else:
+            rendered_conn_default = _normalize_computed_default(
+                rendered_conn_default
+            )
+    else:
+        rendered_conn_default = ""
+
+    if rendered_metadata_default != rendered_conn_default:
+        _warn_computed_not_supported(tname, cname)
+
+
+def _warn_computed_not_supported(tname, cname):
+    util.warn("Computed default on %s.%s cannot be modified" % (tname, cname))
+
+
 @comparators.dispatch_for("column")
 def _compare_server_default(
     autogen_context,
@@ -920,15 +994,34 @@ def _compare_server_default(
         # Once SQLAlchemy can reflect "GENERATED" as the "computed" element,
         # we would also want to ignore and/or warn for changes vs. the
         # metadata (or support backend specific DDL if applicable).
-        return False
+        if not sqla_compat.has_computed_reflection:
+            return False
 
+        else:
+            return _compare_computed_default(
+                autogen_context,
+                alter_column_op,
+                schema,
+                tname,
+                cname,
+                conn_col,
+                metadata_col,
+            )
     rendered_metadata_default = _render_server_default_for_compare(
         metadata_default, metadata_col, autogen_context
     )
 
-    rendered_conn_default = (
-        conn_col.server_default.arg.text if conn_col.server_default else None
-    )
+    if sqla_compat.has_computed_reflection and isinstance(
+        conn_col.server_default, sa_schema.Computed
+    ):
+        _warn_computed_not_supported(tname, cname)
+        return False
+    else:
+        rendered_conn_default = (
+            conn_col.server_default.arg.text
+            if conn_col.server_default
+            else None
+        )
 
     alter_column_op.existing_server_default = conn_col_default
 
