@@ -7,7 +7,7 @@ from .script import ScriptDirectory
 
 
 def list_templates(config):
-    """List available templates
+    """List available templates.
 
     :param config: a :class:`.Config` object.
 
@@ -25,7 +25,7 @@ def list_templates(config):
     config.print_stdout("\n  alembic init --template generic ./scripts")
 
 
-def init(config, directory, template="generic"):
+def init(config, directory, template="generic", package=False):
     """Initialize a new scripts directory.
 
     :param config: a :class:`.Config` object.
@@ -35,20 +35,29 @@ def init(config, directory, template="generic"):
     :param template: string name of the migration environment template to
      use.
 
+    :param package: when True, write ``__init__.py`` files into the
+     environment location as well as the versions/ location.
+
+     .. versionadded:: 1.2
+
+
     """
 
-    if os.access(directory, os.F_OK):
-        raise util.CommandError("Directory %s already exists" % directory)
+    if os.access(directory, os.F_OK) and os.listdir(directory):
+        raise util.CommandError(
+            "Directory %s already exists and is not empty" % directory
+        )
 
     template_dir = os.path.join(config.get_template_directory(), template)
     if not os.access(template_dir, os.F_OK):
         raise util.CommandError("No such template %r" % template)
 
-    util.status(
-        "Creating directory %s" % os.path.abspath(directory),
-        os.makedirs,
-        directory,
-    )
+    if not os.access(directory, os.F_OK):
+        util.status(
+            "Creating directory %s" % os.path.abspath(directory),
+            os.makedirs,
+            directory,
+        )
 
     versions = os.path.join(directory, "versions")
     util.status(
@@ -73,6 +82,14 @@ def init(config, directory, template="generic"):
             output_file = os.path.join(directory, file_)
             script._copy_file(file_path, output_file)
 
+    if package:
+        for path in [
+            os.path.join(os.path.abspath(directory), "__init__.py"),
+            os.path.join(os.path.abspath(versions), "__init__.py"),
+        ]:
+            file_ = util.status("Adding %s" % path, open, path, "w")
+            file_.close()
+
     util.msg(
         "Please edit configuration/connection/logging "
         "settings in %r before proceeding." % config_file
@@ -196,6 +213,11 @@ def revision(
         ):
             script_directory.run_env()
 
+        # the revision_context now has MigrationScript structure(s) present.
+        # these could theoretically be further processed / rewritten *here*,
+        # in addition to the hooks present within each run_migrations() call,
+        # or at the end of env.py run_migrations_online().
+
     scripts = [script for script in revision_context.generate_scripts()]
     if len(scripts) == 1:
         return scripts[0]
@@ -409,7 +431,7 @@ def history(config, rev_range=None, verbose=False, indicate_current=False):
 
 
 def heads(config, verbose=False, resolve_dependencies=False):
-    """Show current available heads in the script directory
+    """Show current available heads in the script directory.
 
     :param config: a :class:`.Config` instance.
 
@@ -476,7 +498,7 @@ def current(config, verbose=False, head_only=False):
     script = ScriptDirectory.from_config(config)
 
     if head_only:
-        util.warn("--head-only is deprecated")
+        util.warn("--head-only is deprecated", stacklevel=3)
 
     def display_version(rev, context):
         if verbose:
@@ -493,13 +515,20 @@ def current(config, verbose=False, head_only=False):
         script.run_env()
 
 
-def stamp(config, revision, sql=False, tag=None):
+def stamp(config, revision, sql=False, tag=None, purge=False):
     """'stamp' the revision table with the given revision; don't
     run any migrations.
 
     :param config: a :class:`.Config` instance.
 
-    :param revision: target revision.
+    :param revision: target revision or list of revisions.   May be a list
+     to indicate stamping of multiple branch heads.
+
+     .. note:: this parameter is called "revisions" in the command line
+        interface.
+
+     .. versionchanged:: 1.2  The revision may be a single revision or
+        list of revisions when stamping multiple branch heads.
 
     :param sql: use ``--sql`` mode
 
@@ -507,27 +536,45 @@ def stamp(config, revision, sql=False, tag=None):
      ``env.py`` scripts via the :class:`.EnvironmentContext.get_tag_argument`
      method.
 
+    :param purge: delete all entries in the version table before stamping.
+
+     .. versionadded:: 1.2
+
     """
 
     script = ScriptDirectory.from_config(config)
 
-    starting_rev = None
-    if ":" in revision:
-        if not sql:
-            raise util.CommandError("Range revision not allowed")
-        starting_rev, revision = revision.split(":", 2)
+    if sql:
+        destination_revs = []
+        starting_rev = None
+        for _revision in util.to_list(revision):
+            if ":" in _revision:
+                srev, _revision = _revision.split(":", 2)
+
+                if starting_rev != srev:
+                    if starting_rev is None:
+                        starting_rev = srev
+                    else:
+                        raise util.CommandError(
+                            "Stamp operation with --sql only supports a "
+                            "single starting revision at a time"
+                        )
+            destination_revs.append(_revision)
+    else:
+        destination_revs = util.to_list(revision)
 
     def do_stamp(rev, context):
-        return script._stamp_revs(revision, rev)
+        return script._stamp_revs(util.to_tuple(destination_revs), rev)
 
     with EnvironmentContext(
         config,
         script,
         fn=do_stamp,
         as_sql=sql,
-        destination_rev=revision,
-        starting_rev=starting_rev,
+        starting_rev=starting_rev if sql else None,
+        destination_rev=util.to_tuple(destination_revs),
         tag=tag,
+        purge=purge,
     ):
         script.run_env()
 
