@@ -17,6 +17,7 @@ from .base import alter_table
 from .base import AlterColumn
 from .base import ColumnComment
 from .base import compiles
+from .base import format_column_name
 from .base import format_table_name
 from .base import format_type
 from .base import RenameTable
@@ -37,6 +38,9 @@ log = logging.getLogger(__name__)
 class PostgresqlImpl(DefaultImpl):
     __dialect__ = "postgresql"
     transactional_ddl = True
+    type_synonyms = DefaultImpl.type_synonyms + (
+        {"FLOAT", "DOUBLE PRECISION"},
+    )
 
     def prep_table_for_batch(self, table):
         for constraint in table.constraints:
@@ -84,7 +88,10 @@ class PostgresqlImpl(DefaultImpl):
             rendered_metadata_default = "'%s'" % rendered_metadata_default
 
         return not self.connection.scalar(
-            "SELECT %s = %s" % (conn_col_default, rendered_metadata_default)
+            text(
+                "SELECT %s = %s"
+                % (conn_col_default, rendered_metadata_default)
+            )
         )
 
     def alter_column(
@@ -148,7 +155,8 @@ class PostgresqlImpl(DefaultImpl):
                 r"nextval\('(.+?)'::regclass\)", column_info["default"]
             )
             if seq_match:
-                info = inspector.bind.execute(
+                info = sqla_compat._exec_on_inspector(
+                    inspector,
                     text(
                         "select c.relname, a.attname "
                         "from pg_class as c join "
@@ -280,8 +288,10 @@ def visit_column_comment(element, compiler, **kw):
     )
 
     return ddl.format(
-        table_name=element.table_name,
-        column_name=element.column_name,
+        table_name=format_table_name(
+            compiler, element.table_name, element.schema
+        ),
+        column_name=format_column_name(compiler, element.column_name),
         comment=comment,
     )
 
